wyzeapy.const API documentation

# wyzeapy.const

View Source

     1#  Copyright (c) 2021. Mulliken, LLC - All Rights Reserved
     2#  You may use, distribute and modify this code under the terms
     3#  of the attached license. You should have received a copy of
     4#  the license with this file. If not, please write to:
     5#  katie@mulliken.net to receive a copy
     6import uuid
     7
     8# Here is where all the *magic* lives
     9PHONE_SYSTEM_TYPE = "1"
    10API_KEY = "WMXHYf79Nr5gIlt3r0r7p9Tcw5bvs6BB4U8O8nGJ"
    11APP_VERSION = "2.18.43"
    12APP_VER = "com.hualai.WyzeCam___2.18.43"
    13APP_NAME = "com.hualai.WyzeCam"
    14PHONE_ID = str(uuid.uuid4())
    15APP_INFO = 'wyze_android_2.19.14'  # Required for the thermostat
    16SC = "9f275790cab94a72bd206c8876429f3c"
    17SV = "9d74946e652647e9b6c9d59326aef104"
    18CLIENT_VER = "2"
    19SOURCE = "ios/WZCameraSDK"
    20APP_PLATFORM = "ios"
    21
    22# Crypto secrets
    23OLIVE_SIGNING_SECRET = 'wyze_app_secret_key_132'  # Required for the thermostat
    24OLIVE_APP_ID = '9319141212m2ik'  # Required for the thermostat
    25FORD_APP_KEY = "275965684684dbdaf29a0ed9"  # Required for the locks
    26FORD_APP_SECRET = "4deekof1ba311c5c33a9cb8e12787e8c"  # Required for the locks

PHONE_SYSTEM_TYPE = '1'
API_KEY = 'WMXHYf79Nr5gIlt3r0r7p9Tcw5bvs6BB4U8O8nGJ'
APP_VERSION = '2.18.43'
APP_VER = 'com.hualai.WyzeCam___2.18.43'
APP_NAME = 'com.hualai.WyzeCam'
PHONE_ID = 'f458275c-b6bf-4a94-87b9-3bc5cd08599f'
APP_INFO = 'wyze_android_2.19.14'
SC = '9f275790cab94a72bd206c8876429f3c'
SV = '9d74946e652647e9b6c9d59326aef104'
CLIENT_VER = '2'
SOURCE = 'ios/WZCameraSDK'
APP_PLATFORM = 'ios'
OLIVE_SIGNING_SECRET = 'wyze_app_secret_key_132'
OLIVE_APP_ID = '9319141212m2ik'
FORD_APP_KEY = '275965684684dbdaf29a0ed9'
FORD_APP_SECRET = '4deekof1ba311c5c33a9cb8e12787e8c'